pub struct Datetime { /* private fields */ }Expand description
AT Protocol datetime (ISO 8601 with specific requirements)
Lexicon datetimes use ISO 8601 format with these requirements:
- Must include timezone (strongly prefer UTC with ‘Z’)
- Requires whole seconds precision minimum
- Supports millisecond and microsecond precision
- Uses uppercase ‘T’ to separate date and time
Examples: "1985-04-12T23:20:50.123Z", "2023-01-01T00:00:00+00:00"
The serialized form is preserved during parsing to ensure exact round-trip serialization.
Implementations
Sourceimpl Datetime
impl Datetime
Sourcepub fn now() -> Self
pub fn now() -> Self
Returns a Datetime which corresponds to the current date and time in UTC.
The timestamp uses microsecond precision.
Sourcepub fn new(dt: DateTime<FixedOffset>) -> Self
pub fn new(dt: DateTime<FixedOffset>) -> Self
Constructs a new Lexicon timestamp.
The timestamp is rounded to microsecond precision.
Sourcepub fn raw_str(s: impl AsRef<str>) -> Self
pub fn raw_str(s: impl AsRef<str>) -> Self
Infallibly parses a new Lexicon timestamp from a compatible str reference
Panics if invalid. Use the fallible trait implementations or deserialize for input you cannot reasonably trust to be properly formatted.
Sourcepub fn timestamp(&self) -> i64
pub fn timestamp(&self) -> i64
Extracts the number of non-leap seconds since January 1, 1970 0:00:00 UTC (aka “UNIX timestamp”).
For full access to the underlying DateTime, use the AsRef<chrono::DateTime<chrono::FixedOffset>> implementation.
Sourcepub fn timestamp_millis(&self) -> i64
pub fn timestamp_millis(&self) -> i64
Extracts the number of non-leap-milliseconds since January 1, 1970 UTC.
For full access to the underlying DateTime, use the AsRef<chrono::DateTime<chrono::FixedOffset>> implementation.
Sourcepub fn timestamp_micros(&self) -> i64
pub fn timestamp_micros(&self) -> i64
Extracts the number of non-leap-microseconds since January 1, 1970 UTC.
For full access to the underlying DateTime, use the AsRef<chrono::DateTime<chrono::FixedOffset>> implementation.