RawData

Enum RawData 

pub enum RawData<'s> {
Show 13 variants Null, Boolean(bool), SignedInt(i64), UnsignedInt(u64), String(CowStr<'s>), Bytes(Bytes), CidLink(Cid<CowStr<'s>>), Array(Vec<RawData<'s>>), Object(BTreeMap<SmolStr, RawData<'s>>), Blob(Blob<CowStr<'s>>), InvalidBlob(Box<RawData<'s>>), InvalidNumber(Bytes), InvalidData(Bytes),
}
Level 1 deserialization of raw atproto data

Maximally permissive with zero inference for cases where you just want to pass through the data and don’t necessarily care if it’s totally valid, or you want to validate later. E.g. lower-level services, PDS implementations, firehose indexers, relay implementations.

Variants



Null

Null value



Boolean(bool)

Boolean value



SignedInt(i64)

Signed integer



UnsignedInt(u64)

Unsigned integer



String(CowStr<'s>)

String value (no type inference)



Bytes(Bytes)

Raw bytes

CID link reference



Array(Vec<RawData<'s>>)

Array of raw values



Object(BTreeMap<SmolStr, RawData<'s>>)

Object/map of raw values



Blob(Blob<CowStr<'s>>)

Valid blob reference



InvalidBlob(Box<RawData<'s>>)

Invalid blob structure (captured for debugging)



InvalidNumber(Bytes)

Invalid number format, generally a floating point number (captured as bytes)



InvalidData(Bytes)

Invalid/unknown data (captured as bytes)

Implementations

Source

impl<'d> RawData<'d>

pub fn as_object(&self) -> Option<&BTreeMap<SmolStr, RawData<'d>>>

Get as object if this is an Object variant

pub fn as_array(&self) -> Option<&Vec<RawData<'d>>>

Get as array if this is an Array variant

pub fn as_str(&self) -> Option<&str>

Get as string if this is a String variant

pub fn as_boolean(&self) -> Option<bool>

Get as boolean if this is a Boolean variant

pub fn as_object_mut(&mut self) -> Option<&mut BTreeMap<SmolStr, RawData<'d>>>

get as object if this is an Object variant

pub fn as_array_mut(&mut self) -> Option<&mut Vec<RawData<'d>>>

Get as array if this is an Array variant

pub fn as_str_mut(&mut self) -> Option<&mut CowStr<'d>>

Get as string if this is a String variant

pub fn as_boolean_mut(&mut self) -> Option<&mut bool>

Get as boolean if this is a Boolean variant

pub fn is_null(&self) -> bool

Check if this is a null value

pub fn type_discriminator(&self) -> Option<&str>

Get the “$type” discriminator field if this is an object with a string “$type” field

This is a shortcut for union type discrimination in AT Protocol. Returns None if this is not an object or if the “$type” field is missing/not a string.

pub fn to_dag_cbor(&self) -> Result<Vec<u8>, EncodeError<TryReserveError>>

Serialize to canonical DAG-CBOR bytes for CID computation

This produces the deterministic CBOR encoding used for content-addressing.

pub fn get_at_path(&'d self, path: &str) -> Option<&'d RawData<'d>>

Get a value at a path within nested RawData structures

Path syntax:

  • .field or field - access object field
  • [0] - access array index
  • Combined: embed.images[0].alt
Example
let data: RawData = ...;
if let Some(alt_text) = data.get_at_path("embed.images[0].alt") {
    println!("Alt text: {}", alt_text.as_str().unwrap());
}
pub fn get_at_path_mut<'a>( &'a mut self, path: &str, ) -> Option<&'a mut RawData<'d>>

Get a mutable reference to a field at the given path

Uses the same path syntax as get_at_path.

pub fn from_cbor(cbor: &'d Ipld) -> Result<Self, AtDataError>

Convert a CBOR-encoded byte slice into a RawData value. Parse a Data value from an IPLD value (CBOR)