pub struct Object<S = DefaultStr>(pub BTreeMap<SmolStr, Data<S>>)
where
S: Bos<str> + AsRef<str>;Expand description
Object/map of AT Protocol data values
Tuple Fields
0: BTreeMap<SmolStr, Data<S>>Implementations
Sourceimpl<S> Object<S>
impl<S> Object<S>
Sourcepub fn get_mut(&mut self, key: &str) -> Option<&mut Data<S>>
pub fn get_mut(&mut self, key: &str) -> Option<&mut Data<S>>
Get a mutable reference to a value by key
Sourcepub fn contains_key(&self, key: &str) -> bool
pub fn contains_key(&self, key: &str) -> bool
Check if a key exists in the object
Sourcepub fn type_discriminator(&self) -> Option<&str>
pub fn type_discriminator(&self) -> Option<&str>
Get the “$type” discriminator field if present and it’s a string
This is a shortcut for union type discrimination in AT Protocol.