WsStream

Struct WsStream 

pub struct WsStream(/* private fields */);
WebSocket message stream

Implementations

Source

impl WsStream

pub fn new<S>(stream: S) -> Self
where S: Stream<Item = Result<WsMessage, StreamError>> + Send + 'static,

Create a new message stream

pub fn into_inner( self, ) -> Pin<Box<dyn Stream<Item = Result<WsMessage, StreamError>> + Send>>

Convert into the inner pinned boxed stream

pub fn tee(self) -> (WsStream, WsStream)

Split this stream into two streams that both receive all messages

Messages are cloned (cheaply via Bytes rc). Spawns a forwarder task. Both returned streams will receive all messages from the original stream. The forwarder continues as long as at least one stream is alive. If the underlying stream errors, both teed streams will end.