pub struct AtStrError {
pub spec: SmolStr,
pub source: String,
pub kind: StrParseKind,
}Expand description
Parsing Error for atproto string types which don’t have third-party specs (e.g. datetime, CIDs, language tags).
spec refers to the final url path segment on atproto.com/specs,
detailing the specification for the type
source is the source string, or part of it
kind is the type of parsing error: [StrParseKind]
Fields
spec: SmolStrAT Protocol spec name this error relates to
source: StringThe source string that failed to parse
kind: StrParseKindThe specific kind of parsing error
Implementations
Sourceimpl AtStrError
impl AtStrError
Sourcepub fn new(spec: &'static str, source: String, kind: StrParseKind) -> Self
pub fn new(spec: &'static str, source: String, kind: StrParseKind) -> Self
Create a new AT string parsing error
Sourcepub fn wrap(spec: &'static str, source: String, error: AtStrError) -> Self
pub fn wrap(spec: &'static str, source: String, error: AtStrError) -> Self
Wrap an existing error with a new spec context
Sourcepub fn disallowed(spec: &'static str, source: &str, disallowed: &[&str]) -> Self
pub fn disallowed(spec: &'static str, source: &str, disallowed: &[&str]) -> Self
something on the provided disallowed list was found in the source string does a substring search for any of the offending strings to get the span
Sourcepub fn too_long(
spec: &'static str,
source: &str,
max: usize,
actual: usize,
) -> Self
pub fn too_long( spec: &'static str, source: &str, max: usize, actual: usize, ) -> Self
Create an error for a string that exceeds the maximum length
Sourcepub fn too_short(
spec: &'static str,
source: &str,
min: usize,
actual: usize,
) -> Self
pub fn too_short( spec: &'static str, source: &str, min: usize, actual: usize, ) -> Self
Create an error for a string below the minimum length
Sourcepub fn missing(spec: &'static str, source: &str, expected: &str) -> Self
pub fn missing(spec: &'static str, source: &str, expected: &str) -> Self
missing component, with what was expected to be found