pub struct WsStream(/* private fields */);Expand description
WebSocket message stream
Implementations
Sourceimpl WsStream
impl WsStream
Sourcepub fn into_inner(
self,
) -> Pin<Box<dyn Stream<Item = Result<WsMessage, StreamError>> + Send>>
pub fn into_inner( self, ) -> Pin<Box<dyn Stream<Item = Result<WsMessage, StreamError>> + Send>>
Convert into the inner pinned boxed stream
Sourcepub fn tee(self) -> (WsStream, WsStream)
pub fn tee(self) -> (WsStream, WsStream)
Split this stream into two streams that both receive all messages
Messages are cloned (cheaply via Bytes rc). Spawns a forwarder task. Both returned streams will receive all messages from the original stream. The forwarder continues as long as at least one stream is alive. If the underlying stream errors, both teed streams will end.